==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/speech/translations/speech_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Parole</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notifications</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Nombre maximum de lettres prononcées</translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation>Message trop long (masculine)</translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation>Message trop long (féminine)</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Voix</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Fréquence</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Base fréquence</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Rythme</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Mélodie</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>Système sonore</translation>
    </message>
    <message>
        <source>aRts</source>
        <translation>aRts</translation>
    </message>
    <message>
        <source>Esd</source>
        <translation>Esd</translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation>Dsp</translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation>Appareil Dsp</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Synthétiseur Klatt (nécessite un dsp)</translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation>Programme de lecture automatique</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation>Lire un texte</translation>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation>Version masculine</translation>
    </message>
    <message>
        <source>Female format</source>
        <translation>Version féminine</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/speech/translations/speech_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Parole</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notifications</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Nombre maximum de lettres prononcées</translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation>Message trop long (masculine)</translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation>Message trop long (féminine)</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Voix</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Fréquence</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Base fréquence</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Rythme</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Mélodie</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>Système sonore</translation>
    </message>
    <message>
        <source>aRts</source>
        <translation>aRts</translation>
    </message>
    <message>
        <source>Esd</source>
        <translation>Esd</translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation>Dsp</translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation>Appareil Dsp</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Synthétiseur Klatt (nécessite un dsp)</translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation>Programme de lecture automatique</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation>Lire un texte</translation>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation>Version masculine</translation>
    </message>
    <message>
        <source>Female format</source>
        <translation>Version féminine</translation>
    </message>
</context>
</TS>
